Package: chipPCR
Type: Package
Title: Toolkit of Helper Functions to Pre-Process Amplification Data
Version: 1.0-2
LazyData: true
Date: 2021-03-02
Authors@R: c(
    person("Stefan", "Roediger", 
	   email = "stefan.roediger@b-tu.de",
	   comment = c(ORCID = "0000-0002-1441-6512"),
      role = c("cre", "aut")),
    person("Michal", "Burdukiewicz", 
      email = "michalburdukiewicz@gmail.com", 
      comment = c(ORCID = "0000-0001-8926-582X"),
      role = "aut"),
    person("Konstantin A.", "Blagodatskikh",
      email = "k.blag@yandex.ru", role = "ctb"),
    person("Andrej-Nikolai", "Spiess", 
      email = "a.spiess@uke.de", 
      role = c("ctb"),
      comment = c(ORCID = "0000-0002-9630-4724")))
Description: A collection of functions to pre-process amplification curve data from polymerase chain reaction (PCR) or isothermal amplification reactions. Contains functions to normalize and baseline amplification curves, to detect both the start and end of an amplification reaction, several smoothers (e.g., LOWESS, moving average, cubic splines, Savitzky-Golay), a function to detect false positive amplification reactions and a function to determine the amplification efficiency. Quantification point (Cq) methods include the first (FDM) and second approximate derivative maximum (SDM) methods (calculated by a 5-point-stencil) and the cycle threshold method. Data sets of experimental nucleic acid amplification systems ('VideoScan HCU', capillary convective PCR (ccPCR)) and commercial systems are included. Amplification curves were generated by helicase dependent amplification (HDA), ccPCR or PCR. As detection system intercalating dyes (EvaGreen, SYBR Green) and hydrolysis probes (TaqMan) were used. For more information see: Roediger et al. (2015) <doi:10.1093/bioinformatics/btv205>. 
License: GPL-3
URL: https://github.com/PCRuniversum/chipPCR
BugReports: https://github.com/PCRuniversum/chipPCR/issues
Depends: R (>= 3.0.0), methods
Suggests: drc, knitr, markdown, qpcR, RDML, rmarkdown, spelling,
        testthat, tinytex, xtable
VignetteBuilder: knitr, rmarkdown
Imports: lmtest, MASS, outliers, ptw, quantreg, Rfit, robustbase,
        shiny, signal
NeedsCompilation: no
Repository: CRAN
Language: en-US
RoxygenNote: 7.1.1
Packaged: 2021-03-04 14:36:42 UTC; tux
Author: Stefan Roediger [cre, aut] (<https://orcid.org/0000-0002-1441-6512>),
  Michal Burdukiewicz [aut] (<https://orcid.org/0000-0001-8926-582X>),
  Konstantin A. Blagodatskikh [ctb],
  Andrej-Nikolai Spiess [ctb] (<https://orcid.org/0000-0002-9630-4724>)
Maintainer: Stefan Roediger <stefan.roediger@b-tu.de>
Date/Publication: 2021-03-05 07:50:03 UTC
Built: R 4.6.0; ; 2026-04-28 15:31:54 UTC; unix
