importFrom(lmtest, bptest)
importFrom(MASS, rlm)
import("methods")
importFrom(outliers, rm.outlier)
importFrom(ptw, whit1, whit2)
importFrom(quantreg, rq)
importFrom(Rfit, rfit)
importFrom(robustbase, lmrob)
importFrom(robustbase, mc)
importFrom(shiny, runApp)
importFrom(signal, sgolayfilt)
importFrom(graphics, abline, arrows, axis, layout, legend,
           lines, matplot, mtext, par, points, polygon,
           rect, rug, text)
importFrom(grDevices, adjustcolor)
importFrom(stats, coef, confint, cor, cor.test, lm, mad, median, na.omit,
           predict, predict.lm, qnorm, quantile, rnorm,
           rstudent, sd, shapiro.test, smooth.spline,
           wilcox.test)
importFrom(utils, head, tail)


exportClasses(
    "amptest",
    "bg",
    "der",
    "refMFI"
)

exportMethods(
  "plot",
  "qqline",
  "qqnorm",
  "show",
  "summary")

export(
  "AmpSim",
  "AmpSim.gui",
	"amptester",
  "amptester.gui",
	"bg.max",
	"CPP",
	"effcalc",
	"fixNA",
	"humanrater",
	"inder",
  "lm.coefs",
	"MFIaggr",
  "MFIaggr.gui",
  "normalizer",
  "plotCurves",
	"rounder",
	"smoother",
	"th.cyc"
)
