amptester - report
========================================================

Date: `r Sys.time()`

```{r, echo=FALSE}

for (i in 1L:length(res.amptest())) {
  cat(colnames(processed.data())[i], "\n")
  x <- res.amptest()[[i]]
  summary(x)
  plot(x)
}
```

amptester settings
-------------------------------------------------------
```{r,results='asis',echo=FALSE}
cat("Input file name: ", input[["input.file"]][["name"]], "\n")
cat("Test chosen: ", input[["amptester.manual"]], "\n")
cat("Noise level: ", input[["amptester.noiselevel"]], "\n")
```